Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(164)

Unified Diff: ui/aura/root_window.h

Issue 9689027: MonitorManager to manage multiple monitors. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: crash fix Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/aura/root_window.h
diff --git a/ui/aura/root_window.h b/ui/aura/root_window.h
index 25108809ff923a09b70ff0bb2d9ce86e17950155..92b60cc8ac14253a31d189d7a14ee5291f07e466 100644
--- a/ui/aura/root_window.h
+++ b/ui/aura/root_window.h
@@ -37,7 +37,6 @@ class RootWindowHost;
class RootWindowObserver;
class KeyEvent;
class MouseEvent;
-class ScreenAura;
class StackingClient;
class ScrollEvent;
class TouchEvent;
@@ -73,7 +72,6 @@ class AURA_EXPORT RootWindow : public ui::CompositorDelegate,
bool cursor_shown() const { return cursor_shown_; }
Window* mouse_pressed_handler() { return mouse_pressed_handler_; }
Window* capture_window() { return capture_window_; }
- const ScreenAura* screen() { return screen_; }
// Shows the root window host.
void ShowRootWindow();
@@ -82,8 +80,8 @@ class AURA_EXPORT RootWindow : public ui::CompositorDelegate,
void SetHostSize(const gfx::Size& size);
gfx::Size GetHostSize() const;
- // Sets the screen's work area insets, this notifies observers too.
- void SetScreenWorkAreaInsets(const gfx::Insets& insets);
+ // Sets the monitor's work area insets, this notifies observers too.
+ void SetMonitorWorkAreaInsets(const gfx::Insets& insets);
// Sets the currently-displayed cursor. If the cursor was previously hidden
// via ShowCursor(false), it will remain hidden until ShowCursor(true) is
@@ -295,8 +293,6 @@ class AURA_EXPORT RootWindow : public ui::CompositorDelegate,
ObserverList<RootWindowObserver> observers_;
- ScreenAura* screen_;
-
// The capture window. When not-null, this window receives all the mouse and
// touch events.
Window* capture_window_;
« ui/aura/monitor.h ('K') | « ui/aura/monitor_manager.cc ('k') | ui/aura/root_window.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698